pub fn shell(
strings: &[&str],
values: Vec<ShellValue>,
) -> Result<ShellCommand, ShellError>Expand description
Parse a template with the default Shell settings (Bun’s $).
pub fn shell(
strings: &[&str],
values: Vec<ShellValue>,
) -> Result<ShellCommand, ShellError>Parse a template with the default Shell settings (Bun’s $).