Module commands

Module commands 

Virtual command implementations

This module contains implementations of shell commands that run in-process without spawning external processes. These provide faster execution and consistent behavior across platforms.

Structs

CommandContext
Context for virtual command execution
VirtualCommandRegistry
Registry of virtual commands

Enums

StreamChunk
A chunk of streaming output

Functions

are_virtual_commands_enabled
Check if virtual commands are enabled
basename
Execute the basename command
cat
Execute the cat command
cd
Execute the cd command
cp
Execute the cp command
dirname
Execute the dirname command
disable_virtual_commands
Disable virtual commands
echo
Execute the echo command
enable_virtual_commands
Enable virtual commands
env
Execute the env command
exit
Execute the exit command
false
Execute the false command
ls
Execute the ls command
mkdir
Execute the mkdir command
mv
Execute the mv command
pwd
Execute the pwd command
rm
Execute the rm command
seq
Execute the seq command
sleep
Execute the sleep command
test
Execute the test command
touch
Execute the touch command
true
Execute the true command
which
Execute the which command
yes
Execute the yes command

Type Aliases

VirtualCommandHandler
Type for virtual command handler functions