pub async fn exit(ctx: CommandContext) -> CommandResultExpand description
Execute the exit command
Exits with the specified code (default 0). Note: This doesn’t actually exit the process, it returns the exit code.
pub async fn exit(ctx: CommandContext) -> CommandResultExecute the exit command
Exits with the specified code (default 0). Note: This doesn’t actually exit the process, it returns the exit code.