pub struct Subprocess { /* private fields */ }Expand description
Live output and process control. Dropping the handle requests termination.
Implementations
Sourceimpl Subprocess
impl Subprocess
pub fn pid(&self) -> Option<u32>
pub async fn wait_for_pid(&mut self) -> Option<u32>
pub fn kill(&mut self, signal: &str)
Sourcepub async fn next(&mut self) -> Option<OutputChunk>
pub async fn next(&mut self) -> Option<OutputChunk>
Read a typed chunk and retain it for wait() unless buffering is off.
Sourcepub async fn wait(self) -> ExecaOutcome
pub async fn wait(self) -> ExecaOutcome
Drain remaining output and wait for the process and its output pumps.