pub fn needs_quoting(value: &str) -> boolExpand description
Check if a string needs quoting for shell usage
Returns true if the string contains characters that would be interpreted specially by the shell.
Examples
use command_stream::quote::needs_quoting;
assert!(!needs_quoting("hello"));
assert!(needs_quoting("hello world"));
assert!(needs_quoting("$PATH"));