Module trace

Module trace 

Trace/logging utilities for command-stream

This module provides verbose logging functionality that can be controlled via environment variables for debugging and development purposes.

Functions

is_trace_enabled
Check if tracing is enabled via environment variables
trace
Trace function for verbose logging
trace_lazy
Trace function with lazy message evaluation