Module error

Module error 

zx-compatible failure formatting (Fail helpers): exit code and errno descriptions plus the multi-line messages attached to failed commands.

Structs

ZxError
Error raised by zx helpers (invalid arguments, unsupported operations, …).

Constants

DOCS_URL
Base URL of the zx documentation, used in some error messages.
ERRNO_CODES
POSIX errno descriptions indexed by the (positive) errno value.
ERROR_DETAILS_LIMIT
Default line limit used by format_error_details.
EXIT_CODES

Functions

errno_message
Description of a (negative, libuv-style) errno value.
exit_code_info
Description of a conventional shell exit code, if known.
format_error_details
Pick the interesting lines of a long output for an error message.
format_error_message
Format the message of a command that could not be run at all (spawn failure, missing working directory, …).
format_exit_message
Format the message of a command that exited unsuccessfully.