pub fn echo<I, S>(parts: I)where
I: IntoIterator<Item = S>,
S: Display,Expand description
Print the arguments joined by spaces followed by a newline (zx echo).
pub fn echo<I, S>(parts: I)where
I: IntoIterator<Item = S>,
S: Display,Print the arguments joined by spaces followed by a newline (zx echo).