spinner

Function spinner 

pub async fn spinner<F: Future>(title: &str, fut: F) -> F::Output
Run fut while showing a spinner titled title on stderr (zx spinner). Verbose logging is disabled for the duration of fut.