Module kill

Module kill 

Process-tree termination (zx kill(pid, signal)).

Constants

SIGTERM
Default signal for kills and timeouts.

Functions

descendants
Pids of all descendants of pid (children first, depth-first), using ps.
kill
Kill a process and all of its descendants (zx kill()).
kill_tree
Send signal to pid, all of its descendants and its process group.
parse_signal
Normalise a signal given as SIGTERM, TERM or a number.
signal_name
Name (SIGTERM, …) of a numeric signal, if it is known.
validate_pid
Validate a pid given as text: it must consist of ASCII digits only.