pub struct ProcessPromise { /* private fields */ }Expand description
Implementations
Sourceimpl ProcessPromise
impl ProcessPromise
Sourcepub fn failed(opts: Options, err: ZxError) -> Self
pub fn failed(opts: Options, err: ZxError) -> Self
A command that fails immediately with err when run.
Sourcepub fn timeout(self, timeout: Duration) -> Self
pub fn timeout(self, timeout: Duration) -> Self
Kill the command after timeout (with the timeout signal).
Sourcepub fn timeout_with(self, timeout: Duration, signal: impl Into<String>) -> Self
pub fn timeout_with(self, timeout: Duration, signal: impl Into<String>) -> Self
Kill the command after timeout with signal.
Sourcepub fn kill_signal(self, signal: impl Into<String>) -> Self
pub fn kill_signal(self, signal: impl Into<String>) -> Self
Default signal for RunningProcess::kill.
Sourcepub fn pipe(self, dest: ProcessPromise) -> ProcessPromise
pub fn pipe(self, dest: ProcessPromise) -> ProcessPromise
Feed this command’s stdout into dest’s stdin; returns dest.
When this command fails (and is not nothrow) the destination is
stopped and inherits its exit code, so the pipeline fails as a whole.
Sourcepub fn pipe_stderr(self, dest: ProcessPromise) -> ProcessPromise
pub fn pipe_stderr(self, dest: ProcessPromise) -> ProcessPromise
Feed this command’s stderr into dest.
Sourcepub fn pipe_stdall(self, dest: ProcessPromise) -> ProcessPromise
pub fn pipe_stdall(self, dest: ProcessPromise) -> ProcessPromise
Feed this command’s interleaved stdout and stderr into dest.
Sourcepub fn pipe_from(self, from: PipeFrom, dest: ProcessPromise) -> ProcessPromise
pub fn pipe_from(self, from: PipeFrom, dest: ProcessPromise) -> ProcessPromise
Feed the selected stream into dest. If dest already has a source,
this command is attached at the head of its pipeline.
Sourcepub async fn pipe_to_file(self, path: impl AsRef<Path>) -> ZxResult
pub async fn pipe_to_file(self, path: impl AsRef<Path>) -> ZxResult
Run the command writing its stdout into the file at path.
Sourcepub async fn pipe_to_file_from(
self,
from: PipeFrom,
path: impl AsRef<Path>,
) -> ZxResult
pub async fn pipe_to_file_from( self, from: PipeFrom, path: impl AsRef<Path>, ) -> ZxResult
Run the command writing the selected stream into the file at path.
Sourcepub fn run_sync(self) -> ZxResult
pub fn run_sync(self) -> ZxResult
Run the command synchronously (on a helper thread with its own runtime, so it is safe to call from inside or outside of tokio).
Sourcepub fn spawn(self) -> RunningProcess
pub fn spawn(self) -> RunningProcess
Start the command in the background (requires a tokio runtime).