Enhanced shell command parser that handles &&, ||, ;, and () operators This allows virtual commands to work properly with shell operators
Structs
- Parsed
Arg - Parsed argument with quote information
- Redirect
- Redirect information
- Shell
Parser - Shell command parser
- Token
- A token with its type and original value
Enums
- Parsed
Command - Types of parsed commands
- Token
Type - Token types for the parser
Functions
- needs_
real_ shell - Check if a command needs shell features we don’t handle
- parse_
shell_ command - Parse a shell command with support for &&, ||, ;, and ()
- tokenize
- Tokenize a shell command string