ShellJS-style asynchronous command calls backed by the portable command
engine. Sessions own their cwd, directory stack, configuration and errors.
See js/docs/SHELLJS_MIGRATION.md for the JavaScript/Rust mapping and limits.
ShellJS-style asynchronous command calls backed by the portable command
engine. Sessions own their cwd, directory stack, configuration and errors.
See js/docs/SHELLJS_MIGRATION.md for the JavaScript/Rust mapping and limits.