pub struct StreamingRunner { /* private fields */ }Expand description
A streaming process runner that allows async iteration over output
Implementations
Sourceimpl StreamingRunner
impl StreamingRunner
Sourcepub fn stream(self) -> OutputStream
pub fn stream(self) -> OutputStream
Start the process and return a stream of output chunks
Sourcepub async fn collect(self) -> Result<CommandResult>
pub async fn collect(self) -> Result<CommandResult>
Run to completion and collect all output