Trace/logging utilities for command-stream
This module provides verbose logging functionality that can be controlled via environment variables for debugging and development purposes.
Functions
- is_
trace_ enabled - Check if tracing is enabled via environment variables
- trace
- Trace function for verbose logging
- trace_
lazy - Trace function with lazy message evaluation