zx-compatible failure formatting (Fail helpers): exit code and errno
descriptions plus the multi-line messages attached to failed commands.
Structs
- ZxError
- Error raised by zx helpers (invalid arguments, unsupported operations, …).
Constants
- DOCS_
URL - Base URL of the zx documentation, used in some error messages.
- ERRNO_
CODES - POSIX errno descriptions indexed by the (positive) errno value.
- ERROR_
DETAILS_ LIMIT - Default line limit used by
format_error_details. - EXIT_
CODES
Functions
- errno_
message - Description of a (negative, libuv-style) errno value.
- exit_
code_ info - Description of a conventional shell exit code, if known.
- format_
error_ details - Pick the interesting lines of a long output for an error message.
- format_
error_ message - Format the message of a command that could not be run at all (spawn failure, missing working directory, …).
- format_
exit_ message - Format the message of a command that exited unsuccessfully.