pub fn tempfile(
name: Option<&str>,
data: Option<&[u8]>,
) -> Result<PathBuf, ZxError>Expand description
Create a temp file and return its path (zx tempfile).
With a name the file is placed in a fresh tempdir; otherwise it is
zx-<random id> in the system temp dir. The file is written with data
or created empty.