Process-tree termination (zx kill(pid, signal)).
Constants
- SIGTERM
- Default signal for kills and timeouts.
Functions
- descendants
- Pids of all descendants of
pid(children first, depth-first), usingps. - kill
- Kill a process and all of its descendants (zx
kill()). - kill_
tree - Send
signaltopid, all of its descendants and its process group. - parse_
signal - Normalise a signal given as
SIGTERM,TERMor a number. - signal_
name - Name (
SIGTERM, …) of a numeric signal, if it is known. - validate_
pid - Validate a pid given as text: it must consist of ASCII digits only.